@@ -3,7 +3,7 @@ package Pongo;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.1';
 
 1;
 
@@ -13,12 +13,6 @@ __END__
 
 Pongo - A Perl MongoDB interface using XS and the MongoDB C driver.
 
-=head1 SYNOPSIS
-
-    use Pongo::Connect;
-
-    # Connect to MongoDB using the Connect module
-
 =head1 DESCRIPTION
 
 Pongo is a collection of MongoDB-related modules written in XS and Perl. It provides a MongoDB interface for Perl by using the MongoDB C driver.
